<?php

/*
Plugin Name: Scan-to-Login
Plugin URI: 
Description: Scan-to-Login Wordpress Plugin.
Version: 1.8
Author: ZapGroup
Author URI: 
License: 
*/

/** Determine which environment we're in, default to live. You can override this by changing $default_env to one of the key values in the $env_urls array below */
require_once('s2l_language.inc');

$default_env = '';

// api environment url's
$env_urls = array(
    'dev'       => 'http://zappermatix/zappertech',
    'qa'        => 'https://zzqa.zapzapadmin.com/qa-zappertech',
    'demo'      => 'https://zzqa.zapzapadmin.com/demo-zappertech',
    'staging'   => 'https://zzqa.zapzapadmin.com/staging-zappertech',
    'prod'      => 'https://zapapi.zapzap.mobi/zappertech'
);

$server_keywords = array('dev', 'qa', 'demo', 'staging');

// use the default environment defined by $default_env if set or try to automatically detect by server name
if (!empty($default_env) && array_key_exists($default_env, $env_urls)) {
    $s2l_api_url = $env_urls[$default_env];
} elseif (!empty($_SERVER['REQUEST_URI'])) {

    $s2l_api_url = $env_urls['prod'];
    $request_uri_parts = explode('/', $_SERVER['REQUEST_URI']);
    
    if (!empty($request_uri_parts[1])) {

        $tmp_site = $request_uri_parts[1];
        $tmp_env = explode('-', $tmp_site);
        
        if (!empty($tmp_env[0])) {

            foreach ($server_keywords as $keyword) {
                
                if (stripos($tmp_env[0], $keyword) !== FALSE && stripos($tmp_env[0], $keyword) !== null) {
                    
                    $s2l_api_url = $env_urls[$keyword];
                    break;
                }
                continue;
            }
        }
    }
}

if (!defined('S2L_API_URL')) {
    define('S2L_API_URL', $s2l_api_url);
}

class Scantologin {

    function enqueue_scripts() {
        wp_enqueue_script('jquery');
        //wp_enqueue_script('zappertech', plugins_url('zappertech.js', __FILE__));
        wp_enqueue_script('zappertech', S2L_API_URL.'/1.1.120/bundles/zappertech');
        wp_enqueue_script('bootstrap', home_url() . '/index.php?zappertech=bootstrap&lang='.get_locale());
        wp_enqueue_style('scantologin', plugins_url('scantologin.css', __FILE__));
    }
    
    function hijack() {
        if(isset($_GET['zappertech'])) {
            switch ($_GET['zappertech']) {
                case 'bootstrap':
                    include 'bootstrap.php';
                    break;
                case 'register':
                    $this->register_user();
                    break;
				case 'authenticate':
					$this->authenticate_user();
					break;
            }
            exit();
        }
    }
    
    function register_user() {
        $scan_to_login_language = new s2l_language();
        $response = array();

        $firstName = sanitize_text_field($_POST['firstName']);
        $lastName = sanitize_text_field($_POST['lastName']);
        
        // User preferred login  
        $cust_username = sanitize_text_field($_POST['username']);
        $email = sanitize_text_field($_POST['email']);
        $password = sanitize_text_field($_POST['password']);

        // Validation
        $response['errors'] = array();
        $response['success'] = FALSE;
        $response['username'] = '';
        $response['password'] = '';
        
        if(empty($firstName))
            $response['errors'][] = $scan_to_login_language->getString('enter_first_name');
        
        if(empty($lastName))
            $response['errors'][] = $scan_to_login_language->getString('enter_last_name');
        
        // Must have both
        if(empty($email) && empty($cust_username))
            $response['errors'][] = $scan_to_login_language->getString('enter_email_address_or_username');

        // Check for both 
        if(username_exists($email) || username_exists($cust_username))
            $response['errors'][] = $scan_to_login_language->getString('already_registered');

        if(empty($password))
            $response['errors'][] = $scan_to_login_language->getString('enter_password');
        
        // Registration
        if(empty($response['errors'])) {
            $userId = wp_create_user($cust_username, $password, $email);
            if(is_wp_error($userId)) {
                $response['errors'][] = $userId->get_error_message();
            } else {
                wp_update_user(array(
                    'ID'            => $userId,
                    'first_name'    => $firstName,
                    'last_name'     => $lastName
                ));
                $response['success'] = TRUE;
                $response['username'] = $cust_username;
                $response['password'] = $password;
            }
        }

        $this->json_encoded($response);
    }
	
	function authenticate_user() {
        $username = sanitize_text_field($_POST['username']);
        $password = sanitize_text_field($_POST['password']);
	
		$user = wp_authenticate_username_password(NULL, $username, $password);
		
		$response = array();
		$response['errors'] = array();
		$response['success'] = FALSE;
        $response['username'] = $username;
        $response['password'] = $password;
		
		if (is_wp_error($user)) {
			$response['errors'] = $user;

        } else {
			$response['success'] = TRUE;
			$response['username'] = $username;
			$response['password'] = $password;
		}

        $this->json_encoded($response);
	}

    function json_encoded($data) {
        @header('Cache-Control: no-cache, must-revalidate');
        @header('Expires: Mon, 26 July 1997 05:00:00 GMT');
        @header('Content-type: application/json');

        echo json_encode($data);
        exit();
    }
	
    function add_admin_menu() {
        add_options_page( 'Scan-to-Login Options', 'Scan-to-Login', 'manage_options', 'scantologin', array($this, 'admin_page'));
    }
    
    function admin_page_save($post) {
        $scan_to_login_language = new s2l_language();
        $results = array(
            'errors' => array(),
            'merchantId' => 0,
            'siteId' => 0,
            'saved' => false,
            'scantologin_self_registration_allowed' => (isset($post['scantologin_self_registration_allowed']) ? 'true' : 'false'),
            'scantologin_demo_mode' => 'false'
        );
        
        if(isset($post['scantologin_merchant_id'])) {
            $results['merchantId'] = $post['scantologin_merchant_id'];
            if(!is_numeric($post['scantologin_merchant_id']) || $post['scantologin_merchant_id'] < 1)
                $results['errors'][] = $scan_to_login_language->getString('enter_merchant_id');
        } else 
            $results['errors'][] = $scan_to_login_language->getString('enter_merchant_id');
        
        if(isset($post['scantologin_site_id'])) { 
            $results['siteId'] = $post['scantologin_site_id'];
            if(!is_numeric($post['scantologin_site_id']) || $post['scantologin_site_id'] < 1)
                $results['errors'][] = $scan_to_login_language->getString('enter_site_id');
        } else
            $results['errors'][] = $scan_to_login_language->getString('enter_site_id');

        if(empty($results['errors'])) {
            update_option('scantologin_merchant_id', $results['merchantId']);
            update_option('scantologin_site_id', $results['siteId']);
            update_option('scantologin_self_registration_allowed', $results['scantologin_self_registration_allowed']);
            update_option('scantologin_demo_mode', $results['scantologin_demo_mode']);
            $results['saved'] = true;
        }
        return $results;
    }

    function admin_page() {
        $scan_to_login_language = new s2l_language();
        $merchantId = get_option('scantologin_merchant_id', 0);
        $siteId = get_option('scantologin_site_id', 0);
        $selfRegistrationAllowed = get_option('scantologin_self_registration_allowed', 'true');
        $demoMode = false;
        $saved = false;
        $errors = array();
        
        if(isset($_POST['submit'])) {
            $saveResults = $this->admin_page_save($_POST);
            $merchantId = $saveResults['merchantId'];
            $siteId = $saveResults['siteId'];
            $selfRegistrationAllowed = $saveResults['scantologin_self_registration_allowed'];
            $demoMode = false;
            $saved = $saveResults['saved'];
            $errors = $saveResults['errors'];
        }
?>

        <div class="wrap">
            <div id="icon-options-general" class="icon32"><br></div>
            <h2><?php echo $scan_to_login_language->getString('s2l_options');?></h2>
            <?php if($saved) { ?>
            <div class="settings-error updated"><p><?php echo $scan_to_login_language->getString('options_saved');?></p></div>
            <?php } ?>
            <?php if(!empty($errors)) { ?>
            <div class="settings-error updated">
                <?php foreach($errors as $error) { ?>
                <p><?php echo $error ?></p>
                <?php } ?>
            </div>
            <?php } ?>
            <form method="post" action="">
                <h3><?php echo $scan_to_login_language->getString('enter_merchant_and_site_id');?></h3>
                <table>
                    <tr>
                        <td style="width: 200px;"><?php echo $scan_to_login_language->getString('merchant_id');?></td>
                        <td><input type="text" name="scantologin_merchant_id" value="<?php echo $merchantId ?>" /></td>
                    </tr>
                    <tr>
                        <td><?php echo $scan_to_login_language->getString('site_id');?></td>
                        <td><input type="text" name="scantologin_site_id" value="<?php echo $siteId ?>" /></td>
                    </tr>
                    <tr>
                        <td style="padding-top: 3px;"><?php echo $scan_to_login_language->getString('allow_any_user_registration');?></td>
                        <td>
                            <input <?php if($selfRegistrationAllowed === 'true') { ?>checked="checked"<?php } ?> style="margin: 2px 0 0 2px;" type="checkbox" name="scantologin_self_registration_allowed" value="true" />
                        </td>
                    </tr>
                </table>
                <p><a href="#" id="scantologin-show-advanced-options" style="display:none;"><?php echo $scan_to_login_language->getString('show_advanced_options');?></a></p>
                <div id="scantologin-advanced-options" style="background: #f3f3f3; width: 350px; padding: 1px 10px 10px 10px; display: none;">
                    <h3><?php echo $scan_to_login_language->getString('advanced_options');?></h3>
                    <table>
                        <tr>
                            <td style="width: 200px;"><?php echo $scan_to_login_language->getString('demo_mode');?></td>
                            <td>
                                <input <?php if($demoMode === 'true') { ?>checked="checked"<?php } ?> type="checkbox" name="scantologin_demo_mode" value="true" />
                            </td>
                        </tr>
                    </table>
                </div>
                <script>
                    (function($){
                        $(function(){
                            $('#scantologin-show-advanced-options').on('click', function() {
                               $('#scantologin-advanced-options').show(); 
                               return false;
                            });
                        });
                    })(jQuery);
                </script>
                <p class="submit">
                    <input type="submit" name="submit" id="submit" class="button button-primary" value="<?php echo $scan_to_login_language->getString('save_changes');?>"/>
                </p>
            </form>
        </div>
        <?php
    }
}

$scantologin = new Scantologin();
add_action('wp_enqueue_scripts', array($scantologin, 'enqueue_scripts'));
add_action('login_form', array($scantologin, 'enqueue_scripts'));
add_action('init', array($scantologin, 'hijack'));
add_action('admin_menu', array($scantologin, 'add_admin_menu'));
